#!/usr/bin/perl

sub open_DEB
{
    my $file = shift;

    return 1
        unless open(DEB, "<$file");
    binmode DEB;

    my $magic;
    return 0 if (read(DEB,$magic, 8) == 8 && $magic eq "!<arch>\n");

    close DEB;  # In case of bad archive, don't leave DEB open
    return 1;
}

# Extract named members from Debian archive (.deb)
# (use for "small" members only. The members to
# extract are defined by the keys in hash $name.
# If found, the value the hash is set to content
# of the file.
#
# Return non-zero, if file is not valid debian archive,
# and 0 otherwise (whether members are found or
# not).
sub get_debian_members
{
    my $file = shift;
    my $name = shift;

    return 1 if (open_DEB($file));

    # ar_name[16];    +00
    # ar_date[12];    +16 (= seconds since)
    # ar_uid[6]       +28 (= "0     ")
    # ar_gid[6]       +34 (= "0     ")
    # ar_mode[8]      +40 (= "100644  ")
    # ar_size[10];    +48
    # ar_fmag[2];     +58 (= "`\n")
    # -------------------
    #                 =60
    my $hdr;
    while (read(DEB, $hdr, 60) == 60)
    {
        my $member = substr($hdr, 0, 16);
        $member =~ s/\s*$//g;
        $member =~ s/\/$//; # Remove one trailing '/', if present
        my $size = substr($hdr, 48, 10);

        return 1
            if (substr($hdr, 58, 2) ne "`\n");
                
        if (exists $name->{$member})
        {
            my $odd = $size & 1;
            my $value;
            my $actual = read(DEB, $value, $size);
            return 1
                unless $actual == $size;
            $name->{$member} = $value;
            # Align pos to even, if size was odd
            seek DEB,1,1 if ($odd);
        }
        else
        {
            seek DEB,($size+1)&~1,1;
        }
    }
    close DEB;
    return 0;
}

my $file = "$ARGV[0]";
my $manifest = {'_aegis' => ''};
get_debian_members($file, $manifest);
$manifest = $manifest->{'_aegis'};
print "$manifest";
