import QtQuick 1.1
import com.nokia.meego 1.0
import "utilities.js" as Util

Dialog {
    id: root
    property variant packageJson
    signal install(int value, bool trusted)
    signal showManifest
    platformStyle: QueryDialogStyle {}
    width: 480
    height: 820
    title: Item {
        id: titleField
        width: parent.width
        height: 96
        Image {
            id: icon
            width: 64
            height: 64
            anchors.bottom: parent.bottom
            smooth: true
            source: packageJson.maemoicon ? ("data:image/png;base64," + packageJson.maemoicon) : "image://theme/icon-m-settings-applications"
        }
        Text {
            color: "white"
            font.pixelSize: 25
            anchors.left: icon.right
            anchors.leftMargin: 10
            anchors.verticalCenter: icon.verticalCenter
            text: packageJson.maemodisplayname ? packageJson.maemodisplayname : packageJson.package
        }
        MouseArea {
            anchors.fill: parent
        }
    }
    content: Item {
        id: queryContent
        height: root.height - buttonColFiller.height - titleField.height
        width: root.width

        Flickable {
            id: queryFlickable
            anchors.left: parent.left
            anchors.leftMargin: 6
            anchors.right: parent.right
            anchors.rightMargin: 6
            anchors.top: parent.top
            anchors.bottom: parent.bottom

            contentHeight: content.height
            flickableDirection: Flickable.VerticalFlick
            clip: true

            interactive: true

            Column {
                id: content
                width: root.width
                spacing: 10

                Text {
                    id: description
                    color: "white"
                    font.pixelSize: 22
                    width: parent.width
                    wrapMode: Text.WordWrap
                    text: packageJson.description ? packageJson.description : ""
                }

                Item {
                    height: maintainerText.height
                    width: parent.width
                    visible: packageJson.maintainer != ""
                    Text {
                        color: "white"
                        font.pixelSize: 22
                        text: "Maintainer: "
                    }
                    Text {
                        id: maintainerText
                        color: "white"
                        font.pixelSize: 22
                        text: packageJson.maintainer
                        anchors.left: parent.left
                        anchors.leftMargin: 120
                        anchors.right: parent.right
                        wrapMode: Text.WrapAnywhere
                    }
                }

                Item {
                    height: homepageText.height
                    width: parent.width
                    visible: packageJson.homepage != ""
                    Text {
                        color: "white"
                        font.pixelSize: 22
                        text: "Homepage: "
                    }
                    Text {
                        id: homepageText
                        color: "white"
                        font.pixelSize: 22
                        text: packageJson.homepage
                        anchors.left: parent.left
                        anchors.leftMargin: 120
                        anchors.right: parent.right
                        wrapMode: Text.WrapAnywhere
                    }
                }

                Item {
                    height: sizeText.height
                    width: parent.width
                    visible: packageJson.installedsize != ""
                    Text {
                        color: "white"
                        font.pixelSize: 22
                        text: "Size: "
                    }
                    Text {
                        id: sizeText
                        color: "white"
                        font.pixelSize: 22
                        text: Util.bytesToSize(packageJson.installedsize)
                        anchors.left: parent.left
                        anchors.leftMargin: 120
                        anchors.right: parent.right
                        wrapMode: Text.WrapAnywhere
                    }
                }

                MyButton {
                    id: manifest
                    width: 400
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: "Show manifest"
                    onClicked: root.showManifest()
                    visible: packageJson.aegismanifest == "included"
                }
            }
        }

        ScrollDecorator {
            id: scrollDecorator
            flickableItem: queryFlickable
            anchors.rightMargin: 10
        }
    }
    buttons: Item {
        id: buttonColFiller
        width: parent.width
        height: buttonCol.height + 40

        anchors.bottom: parent.bottom

        Item {id: dummy; anchors.fill:  parent}

        Column {
            id: buttonCol
            anchors.top: parent.top
            width: 400
            spacing: 10

            height: regular.height + trusted.height + 20
                    //+ anchors.buttonTopMargin  + spacing

            anchors.centerIn: parent

            MyButton {
                id: regular
                width: parent.width
                text: "Regular installation"
                __dialogButton: true
                platformStyle: MyButtonStyle {inverted: true}
                onClicked: install(0, false)
                checked: true
            }

            Item {
                id: trusted
                width: parent.width
                height: dpkg.height + (gdebiinstalled ? (gdebi.height + 10) : 0)

                LabeledSwitch {
                    id: trustedOrigin
                    anchors.verticalCenter: parent.verticalCenter
                    width: 170
                    anchors.left: parent.left
                    text: "Trusted"
                    visible: openmode || aegishacked
                }

                MyButton {
                    id: dpkg
                    anchors.top: parent.top
                    width: 200
                    anchors.right: parent.right
                    text: "Dpkg"
                    __dialogButton: true
                    platformStyle: MyButtonStyle {inverted: true}
                    onClicked: {
                        install(1, trustedOrigin.checked)
                    }
                }

                MyButton {
                    id: gdebi
                    width: 200
                    anchors.right: parent.right
                    anchors.bottom: parent.bottom
                    text: "GDebi"
                    __dialogButton: true
                    platformStyle: MyButtonStyle {inverted: true}
                    onClicked: {
                        install(2, trustedOrigin.checked)
                    }
                    visible: gdebiinstalled
                }
            }
        }
    }
}
