import QtQuick 1.1
import com.nokia.meego 1.1

Page {
    id: page
    orientationLock: PageOrientation.LockPortrait

    function start(process, params, trusted) {
        consoleText.text = ""
        consoleText.text += "<br><font color=\"#40D0FF\">" + process
        for (var i=0; i<params.length; i++) {
            consoleText.text += " "
            consoleText.text += params[i]
        }
        consoleText.text += "</font><br>"
        ConsoleRead.execAndStartReading(process, params, trusted)
    }

    Connections {
        target: ConsoleRead
        onOutput: {
            consoleLog.text += data
            if (isError)
                consoleText.text += "<font color=\"#00FF00\">" + data.replace("\n", "<br>") + "</font>"
            else
                consoleText.text += "<font color=\"#FFFFFF\">" + data.replace("\n", "<br>") + "</font>"
            flick.contentY = flick.contentHeight > flick.height ? (flick.contentHeight - flick.height) : 0
        }
        onFinished: {
            close.enabled = true
            if (exitCode == 0) {
                consoleText.text += "<br><font color=\"#00FF00\">Installation finished</font>"
            }
            else {
                consoleText.text += "<br><font color=\"#FF0000\">Installation failed</font>"
            }
            flick.contentY = flick.contentHeight > flick.height ? (flick.contentHeight - flick.height) : 0
        }
    }

    Rectangle {
        id: pageHeader
        anchors {
            top: page.top
            left: page.left
            right: page.right
        }

        height: parent.width < parent.height ? 72 : 46
        width: parent.width
        color: "green"

        Text {
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 16

            font.pixelSize: 32
            color: "white"
            text: "Console"
        }
    }

    Flickable {
        id: flick
        anchors.top: pageHeader.bottom
        anchors.topMargin: 10
        anchors.left: page.left
        anchors.leftMargin: 6
        anchors.right: page.right
        anchors.rightMargin: 6
        anchors.bottom: buttons.top
        anchors.bottomMargin: 10
        clip: true
        contentHeight: consoleText.height

        Text {
            id: consoleText
            color: "white"
            font.family: "Courier New"
            font.pixelSize: 16
            width: parent.width
            wrapMode: Text.WrapAnywhere
        }
    }

    ScrollDecorator {
        flickableItem: flick
    }

    Row {
        id: buttons
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: page.bottom
        anchors.bottomMargin: 10
        width: 400
        height: close.height
        spacing: 10

        MyButton {
            id: close
            enabled: false
            text: "Done"
            width: 300
            __dialogButton: true
            platformStyle: MyButtonStyle {inverted: true}
            onClicked: Qt.quit()
            checked: true
        }
        MyButton {
            id: copy
            enabled: close.enabled
            text: "Log"
            width: 90
            __dialogButton: true
            platformStyle: MyButtonStyle {inverted: true}
            onClicked: {
                consoleLog.copyToClipboard()
                consoleText.text += "<br><font color=\"#00FF00\">Log copied to clipboard</font>"
            }
        }
    }

    TextArea {
        id: consoleLog
        visible: false
        function copyToClipboard() {
            consoleLog.selectAll()
            consoleLog.copy()
        }
    }
}
