import com.nokia.meego 1.0
import QtQuick 1.1
import org.coderus.GConf 1.0

Item {
    id: root
    property string color_level: "/desktop/meego/status_menu/brightness-qml/color_level"
    property string color_level_border: "/desktop/meego/status_menu/brightness-qml/color_level_border"
    property string color_system: "/desktop/meego/status_menu/brightness-qml/color_system"
    property string color_system_border: "/desktop/meego/status_menu/brightness-qml/color_system_border"
    property string color_background: "/desktop/meego/status_menu/brightness-qml/color_background"
    property string color_background_border: "/desktop/meego/status_menu/brightness-qml/color_background_border"

    GConf {
        id: gconf
    }

    Component.onCompleted: {
        var colorLevel = gconf.get(color_level, "#FF0000")
        systemColor.color = colorLevel

        var colorLevelBorder = gconf.get(color_level_border, "#FF0000")
        systemColor.border.color = colorLevelBorder

        var systemLevel = gconf.get(color_system, "#00FF00")
        hackyColor.color = systemLevel

        var systemLevelBorder = gconf.get(color_system_border, "#00FF00")
        hackyColor.border.color = systemLevelBorder

        var colorBackbround = gconf.get(color_background, "#323232")
        bgColor.color = colorBackbround

        var colorBackbroundBorder = gconf.get(color_background_border, "#323232")
        bgColor.border.color = colorBackbroundBorder

    }

    Column {
        id: content
        spacing: 10
        anchors.left: root.left
        anchors.right: root.right
        anchors.leftMargin: 16
        anchors.rightMargin: 16

        Rectangle {
            width: 1
            height: 10
            color: "transparent"
        }

        Separator {
            width: parent.width
            title: "System level"
        }

        Rectangle {
            id: systemColor
            width: parent.width
            height: 40
            border.width: 1

            function changeColor() {
                color = dialog.color
                dialog.accepted.disconnect(systemColor.changeColor)
                gconf.set(color_level, dialog.color)
            }

            function changeBorder() {
                border.color = dialog.color
                dialog.accepted.disconnect(systemColor.changeBorder)
                gconf.set(color_level_border, dialog.color)
            }
        }

        LabeledButton {
            width: parent.width
            text: systemColor.color
            buttonText: "Change fill"
            onClicked: {
                dialog.accepted.connect(systemColor.changeColor)
                dialog.titleText = buttonText
                dialog.color = systemColor.color
                dialog.open()
            }
        }

        LabeledButton {
            width: parent.width
            text: systemColor.border.color
            buttonText: "Change border"
            onClicked: {
                dialog.accepted.connect(systemColor.changeBorder)
                dialog.titleText = buttonText
                dialog.color = systemColor.border.color
                dialog.open()
            }
        }

        Separator {
            width: parent.width
            title: "Hacky level"
        }

        Rectangle {
            id: hackyColor
            width: parent.width
            height: 40
            border.width: 1

            function changeColor() {
                color = dialog.color
                dialog.accepted.disconnect(hackyColor.changeColor)
                gconf.set(color_system, dialog.color)
            }

            function changeBorder() {
                border.color = dialog.color
                dialog.accepted.disconnect(hackyColor.changeBorder)
                gconf.set(color_system_border, dialog.color)
            }
        }

        LabeledButton {
            width: parent.width
            text: hackyColor.color
            buttonText: "Change fill"
            onClicked: {
                dialog.accepted.connect(hackyColor.changeColor)
                dialog.titleText = buttonText
                dialog.color = hackyColor.color
                dialog.open()
            }
        }

        LabeledButton {
            width: parent.width
            text: hackyColor.border.color
            buttonText: "Change border"
            onClicked: {
                dialog.accepted.connect(hackyColor.changeBorder)
                dialog.titleText = buttonText
                dialog.color = hackyColor.border.color
                dialog.open()
            }
        }

        Separator {
            width: parent.width
            title: "Background"
        }

        Rectangle {
            id: bgColor
            width: parent.width
            height: 40
            border.width: 1

            function changeColor() {
                color = dialog.color
                dialog.accepted.disconnect(bgColor.changeColor)
                gconf.set(color_background, dialog.color)
            }

            function changeBorder() {
                border.color = dialog.color
                dialog.accepted.disconnect(bgColor.changeColor)
                gconf.set(color_background_border, dialog.color)
            }
        }

        LabeledButton {
            width: parent.width
            text: bgColor.color
            buttonText: "Change fill"
            onClicked: {
                dialog.accepted.connect(bgColor.changeColor)
                dialog.titleText = buttonText
                dialog.color = bgColor.color
                dialog.open()
            }
        }

        LabeledButton {
            width: parent.width
            text: bgColor.border.color
            buttonText: "Change border"
            onClicked: {
                dialog.accepted.connect(bgColor.changeBorder)
                dialog.titleText = buttonText
                dialog.color = bgColor.border.color
                dialog.open()
            }
        }

        Rectangle {
            width: 1
            height: 10
            color: "transparent"
        }
    }

    ColorSelectionDialog {
        id: dialog
    }
}
