import QtQuick 1.1
import com.nokia.meego 1.1
import QtMobility.feedback 1.1

Window {
    id: root

    property string _activeProfile: "general"
    property bool _vibrateEnabled: true
    property string _PROFILED_VIBRATE_VALUE: "vibrating.alert.enabled"

    property string _SHORT_ACTION: "/apps/power-menu-qml/short_action"
    property string _LIKE_SYMBIAN: "/apps/power-menu-qml/likeSymbian"
    property string _ALIGN_CENTER: "/apps/power-menu-qml/alignTextCenter"
    property string _USE_DOUBLEPRESS: "/apps/power-menu-qml/useDoublePress"
    property string _SHOW_PROFILE: "/apps/power-menu-qml/showProfileControls"
    property string _SHOW_POWEROFF: "/apps/power-menu-qml/showPoweroff"
    property string _SHOW_REBOOT: "/apps/power-menu-qml/showReboot"
    property string _SHOW_KILLHOME: "/apps/power-menu-qml/showKillHome"
    property string _SHOW_KILLSYSUID: "/apps/power-menu-qml/showKillSysuid"
    property string _SHOW_SCREENSHOT: "/apps/power-menu-qml/showScreenshot"

    property bool useSymbianBehaviour: false
    property bool alignTextCenter: false
    property bool useDoublePress: false
    property bool showProfileControls: true
    property bool showPoweroff: true
    property bool showReboot: true
    property bool showKillHome: true
    property bool showKillSysuid: true
    property bool showScreenshot: true
    property string shortAction: "tklock-lock"

    Component.onCompleted: {
        screen.allowSwipe = false
        screen.allowedOrientations = Screen.Portrait
        _activeProfile = profileclient.activeProfile()
        _vibrateEnabled = (profileclient.profileProperty(_activeProfile, _PROFILED_VIBRATE_VALUE) == "On")
        gconf.addWatcher(_LIKE_SYMBIAN)
        gconf.addWatcher(_ALIGN_CENTER)
        gconf.addWatcher(_USE_DOUBLEPRESS)
        gconf.addWatcher(_SHOW_PROFILE)
        gconf.addWatcher(_SHOW_POWEROFF)
        gconf.addWatcher(_SHOW_REBOOT)
        gconf.addWatcher(_SHOW_KILLHOME)
        gconf.addWatcher(_SHOW_KILLSYSUID)
        gconf.addWatcher(_SHOW_SCREENSHOT)
        gconf.addWatcher(_SHORT_ACTION)
    }

    Connections {
        target: profileclient
        onProfileChanged: {
            _activeProfile = profile
        }
        onPropertyChanged: {
            if (name != _PROFILED_VIBRATE_VALUE)
                return;

            if (profile != profileclient.activeProfile())
                return;

            _vibrateEnabled = (value == "On")
        }
    }

    Connections {
        target: gconf
        onValueChanged: {
            switch (key) {
            case _LIKE_SYMBIAN: {
                useSymbianBehaviour = value
                break
            }
            case _ALIGN_CENTER: {
                alignTextCenter = value
                break
            }
            case _USE_DOUBLEPRESS: {
                useDoublePress = value
                break
            }
            case _SHOW_PROFILE: {
                showProfileControls = value
                break
            }
            case _SHOW_POWEROFF: {
                showPoweroff = value
                break
            }
            case _SHOW_REBOOT: {
                showReboot = value
                break
            }
            case _SHOW_KILLHOME: {
                showKillHome = value
                break
            }
            case _SHOW_KILLSYSUID: {
                showKillSysuid = value
                break
            }
            case _SHOW_SCREENSHOT: {
                showScreenshot = value
                break
            }
            case _SHORT_ACTION: {
                shortAction = value
                break
            }
            }
        }
    }

    Connections {
        target: client
        onDisplayActiveChanged: {
            if (!client.displayActive && dialog.status == DialogStatus.Open)
                dialog.accept()
        }
    }

    Connections {
        target: powerButton
        onPowerButtonLongPressed: {
            if (!client.displayLocked && client.displayActive) { //display on and not locked
                if (dialog.status == DialogStatus.Closed) { //dialog closed
                    if (!useDoublePress) { // double press off
                        if (useSymbianBehaviour)
                            items.selectedIndex = 0
                        else
                            items.selectedIndex = -1
                        view.showFullScreen()
                        showTimer.start()
                        console.log(JSON.stringify(client.modulesList()))
                    }
                    else { // double press on
                        client.shutdown()
                    }
                }
                else { //dialog opened
                    if (!useDoublePress) { // double press off
                        if (!useSymbianBehaviour) { // legacy off
                            dialog.accept()
                        }
                        else { // legacy on
                            items.select(items.selectedIndex)
                            dialog.accept()
                        }
                    }
                    else { // double press on
                        if (!useSymbianBehaviour) { // legacy off
                            client.shutdown()
                        }
                        else { // legacy on
                            items.select(items.selectedIndex)
                        }
                    }
                }
            }
            else { //display off or locked
                // do nothing for now
            }
        }
        onPowerButtonShortClicked: {
            if (dialog.status == DialogStatus.Closed) { // dialog closed
                if (shortAction == "tklock-lock" && !client.displayLocked) {
                    client.displayLocked = true
                }
                else if (shortAction == "tklock-unlock" && client.displayLocked) {
                    client.displayLocked = false
                }
                else if (shortAction == "tklock-both") {
                    client.displayLocked = !client.displayLocked
                }
            }
            else { // dialog opened
                if (useSymbianBehaviour) {
                    items.next()
                }
            }
        }
        onPowerButtonDoubleClicked: {
            if (!client.displayLocked && client.displayActive) { //display on and not locked
                if (useDoublePress) {
                    if (dialog.status == DialogStatus.Closed) {
                        if (useSymbianBehaviour)
                            items.selectedIndex = 0
                        else
                            items.selectedIndex = -1
                        view.showFullScreen()
                        showTimer.start()
                    }
                    else {
                        dialog.accept()
                    }
                }
            }
        }
    }

    color: "#00000000"

    Item {
        id: mainItem
        width: 480
        height: 854
        x: 0
        y: 0
        visible: true

        Dialog {
            id: dialog
            __fadeInDelay: 0
            __fadeInDuration: 300
            __fadeOutDelay: 0
            __fadeOutDuration: 300
            __dim: 0.9
            width: 440
            visible: mainItem.visible
            title: Item {
                height: 80
                width: parent.width
                Text {
                    id: titleText
                    text: "Power Menu"
                    color: "white"
                    font.pixelSize: 32
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.left: parent.left
                    anchors.leftMargin: 6
                }
                Rectangle {
                    width: parent.width
                    height: 1
                    anchors.top: titleText.bottom
                    anchors.topMargin: 5
                    color: "gray"
                }
            }
            content: Column {
                id: items
                width: parent.width
                spacing: 10
                property int selectedIndex: 0

                function next() {
                    if (listMenu.visibilityCount > 0) {
                        if (selectedIndex < (listMenu.count - 1))
                            selectedIndex++
                        else
                            selectedIndex = 0
                        while (!listMenu.itemAt(selectedIndex).visible) {
                            selectedIndex++
                            if (selectedIndex == listMenu.count)
                                selectedIndex = 0
                        }
                    }
                }

                function select (index) {
                    switch (index) {
                    case 0: {
                        dialog.accept()
                        client.shutdown()
                        break
                    }
                    case 1: {
                        dialog.accept()
                        client.reboot()
                        break
                    }
                    case 2: {
                        dialog.accept()
                        client.exec("killall meegotouchhome")
                        break
                    }
                    case 3: {
                        dialog.accept()
                        client.exec("killall sysuid")
                        break
                    }
                    case 4: {
                        dialog.accept()
                        captureScreen.start()
                        break
                    }
                    }
                }

                Row {
                    spacing: 10
                    height: visible ? 96 : 0
                    visible: showProfileControls

                    ClickableImage {
                        id: profileImage
                        width: 96
                        height: 96
                        imageSource: (_activeProfile == "silent" ?
                                          "/usr/share/power-menu-qml/icons/silent.png" :
                                          "/usr/share/power-menu-qml/icons/general.png")
                        onClicked: {
                            if (_activeProfile == "silent")
                                profileclient.setProfile("general")
                            else
                                profileclient.setProfile("silent")
                        }
                    }

                    ClickableImage {
                        id: vibrateImage
                        width: 96
                        height: 96
                        imageSource: (_vibrateEnabled ?
                                          "/usr/share/power-menu-qml/icons/vibrate_on.png" :
                                          "/usr/share/power-menu-qml/icons/vibrate_off.png")
                        onClicked: {
                            profileclient.setProfileProperty(_activeProfile, _PROFILED_VIBRATE_VALUE, (_vibrateEnabled ? "Off" : "On"));
                        }
                    }
                }

                function getVisibility(index) {
                    switch (index) {
                    case 0: {
                        return showPoweroff
                        break
                    }
                    case 1: {
                        return showReboot
                        break
                    }
                    case 2: {
                        return showKillHome
                        break
                    }
                    case 3: {
                        return showKillSysuid
                        break
                    }
                    case 4: {
                        return showScreenshot
                        break
                    }
                    }
                }

                Repeater {
                    id: listMenu
                    property int visibilityCount: (showPoweroff ? 1 : 0)
                                                + (showReboot ? 1 : 0)
                                                + (showKillHome ? 1 : 0)
                                                + (showKillSysuid ? 1 : 0)
                                                + (showScreenshot ? 1 : 0)
                    width: parent.width
                    model: ListModel {
                        ListElement { text: "Power off"; icon: "/usr/share/power-menu-qml/icons/shutdown.png" }
                        ListElement { text: "Reboot"; icon: "/usr/share/power-menu-qml/icons/reboot.png" }
                        ListElement { text: "Restart mthome"; icon: "/usr/share/power-menu-qml/icons/restart.png" }
                        ListElement { text: "Restart sysuid"; icon: "/usr/share/power-menu-qml/icons/restart.png" }
                        ListElement { text: "Screenshot"; icon: "/usr/share/power-menu-qml/icons/screenshot.png" }
                    }

                    delegate: ClickableItem {
                        visible: items.getVisibility(index)
                        height: visible ? 60 : 0
                        width: parent.width
                        forceHighlight: index == items.selectedIndex
                        alignCenter: root.alignTextCenter
                        text: model.text
                        iconSource: model.icon
                        onClicked: {
                            items.selectedIndex = -1
                            items.select(index)
                        }
                        onPressed: items.selectedIndex = -1
                    }
                }
            }
            buttons: Item { width: 1; height: 1 }
            onAccepted: hideTimer.start()
            onRejected: hideTimer.start()
            onStatusChanged: {
                if (status == DialogStatus.Opening) {
                    popupEffect.repeat(3)
                }
            }
        }

        Timer {
            id: showTimer
            interval: 200
            repeat: false
            running: false
            triggeredOnStart: false
            onTriggered: dialog.open()
        }

        Timer {
            id: hideTimer
            interval: 400
            repeat: false
            running: false
            triggeredOnStart: false
            onTriggered: view.hide()
        }

        Timer {
            id: captureScreen
            interval: 1000
            repeat: false
            running: false
            triggeredOnStart: false
            onTriggered: {
                var obj = client.screenShot()
                if (dialog.status == DialogStatus.Open)
                    dialog.accept()
                screenItem.start(obj)
            }
        }
    }

    Item {
        id: screenItem
        width: 480
        height: 854
        x: 0
        y: 0
        visible: false

        function start(obj) {
            mainItem.visible = false
            screenItem.visible = true
            screenImage.source = obj[0]
            screenRot.angle = 90 - parseInt(obj[1])
            screenImage.width = screenImage.sourceSize.width
            screenImage.height = screenImage.sourceSize.height
            screenImage.opacity = 1.0
            view.showFullScreen()
            screenTimer.start()
        }

        Image {
            id: screenImage
            anchors.centerIn: parent

            PropertyAnimation {
                id: animate
                target: screenImage
                properties: "height,width,opacity"
                to: 0
                duration: 500
                onCompleted: {
                    view.hide()
                    screenItem.visible = false
                    mainItem.visible = true
                }
            }

            transform: Rotation {id: screenRot; origin.x: screenImage.width / 2; origin.y: screenImage.height / 2; angle: 0}
        }

        Timer {
            id: screenTimer
            interval: 1000
            repeat: false
            running: false
            triggeredOnStart: false
            onTriggered: {
                popupEffect.repeat(4)
                animate.start()
            }
        }
    }

    ThemeEffect {
        id: popupEffect
        effect: ThemeEffect.PopupOpen
        function repeat(j) {
            for (var i=0; i<j; i++)
                play()
        }
    }
}
