import QtQuick 1.1
import com.nokia.meego 1.0

FocusScope {
    id: root
    width: 480
    height: content.height + 20

    Component.onCompleted: {
        theme.inverted = true
        forceActiveFocus()
    }

    //disabled Flickable since using internal Dcp page pans to make Text fields working
    /*Flickable {
        id: flick
        anchors.fill: root
        anchors.leftMargin: 8
        anchors.rightMargin: 8
        clip: true
        contentHeight: content.height + 10
        interactive: true*/

        Column {
            id: content
            width: parent.width
            spacing: 5

            Item {
                id: title
                width: parent.width
                height: 90

                Label {
                    text: "Power Menu QML"
                    font.pixelSize: 30
                    anchors.leftMargin: 8
                    anchors.left: parent.left
                    anchors.right: parent.right
                    wrapMode: Text.NoWrap
                    anchors.top: parent.top
                    anchors.topMargin: 8
                    color: "white"
                }

                Rectangle {
                    width: parent.width
                    height: 1
                    anchors.bottom: parent.bottom
                    anchors.bottomMargin: 10
                    color: "darkgrey"
                }
            }

            Separator {
                width: parent.width
                title: "Options"
            }

            LabeledCheck {
                id: legacy
                text: "Nokia legacy behaviour"
                width: parent.width
                checked: useSymbianBehaviour
                onCheckedChanged: {
                    if (root.activeFocus) {
                        QMLHelper.gconfSet("/apps/power-menu-qml/likeSymbian", checked)
                        QMLHelper.setLegacy(checked)
                        freezeMce.freeze()
                    }
                }
            }

            LabeledCheck {
                text: "Align text to center"
                width: parent.width
                checked: alignTextCenter
                onCheckedChanged: QMLHelper.gconfSet("/apps/power-menu-qml/alignTextCenter", checked)
            }


            Separator {
                width: parent.width
                title: "Double click action"
            }

            LabeledCheck {
                id: double_menu
                text: "Use double-click to show menu"
                width: parent.width
                checked: useDoubleClick
                onCheckedChanged: {
                    if (root.activeFocus) {
                        QMLHelper.gconfSet("/apps/power-menu-qml/useDoublePress", checked)
                        QMLHelper.gconfSet("/apps/power-menu-qml/double_action", checked ? "dbus-signal-powerkey_double_ind" : (double_both.checked ? "tklock-both" : "disabled"))
                        QMLHelper.setDouble()
                        freezeMce.freeze()
                    }
                }
            }

            LabeledCheck {
                id: double_both
                text: "Use double-click to unlock"
                width: parent.width
                checked: doubleAction == "tklock-both"
                enabled: !double_menu.checked
                onCheckedChanged: {
                    if (root.activeFocus) {
                        QMLHelper.gconfSet("/apps/power-menu-qml/double_action", checked ? "tklock-both" : "disabled")
                        QMLHelper.setDouble()
                        freezeMce.freeze()
                    }
                }
            }

            Separator {
                width: parent.width
                title: "Short click action"
            }

            LabeledRadio {
                id: tklock_lock
                text: "Only lock"
                width: parent.width
                checked: shortAction == "tklock-lock"
                onCheckedChanged: {
                    if (root.activeFocus && checked) {
                        QMLHelper.gconfSet("/apps/power-menu-qml/short_action", "tklock-lock")
                        tklock_unlock.checked = false
                        tklock_both.checked = false
                        if (!legacy.checked) {
                            QMLHelper.setShort()
                        }
                        freezeMce.freeze()
                    }
                }
            }

            LabeledRadio {
                id: tklock_unlock
                text: "Only unlock"
                width: parent.width
                checked: shortAction == "tklock-unlock"
                onCheckedChanged: {
                    if (root.activeFocus && checked) {
                        QMLHelper.gconfSet("/apps/power-menu-qml/short_action", "tklock-unlock")
                        tklock_lock.checked = false
                        tklock_both.checked = false
                        if (!legacy.checked) {
                            QMLHelper.setShort()
                        }
                        freezeMce.freeze()
                    }
                }
            }

            LabeledRadio {
                id: tklock_both
                text: "Both lock/unlock"
                width: parent.width
                checked: shortAction == "tklock-both"
                onCheckedChanged: {
                    if (root.activeFocus && checked) {
                        QMLHelper.gconfSet("/apps/power-menu-qml/short_action", "tklock-both")
                        tklock_unlock.checked = false
                        tklock_lock.checked = false
                        if (!legacy.checked) {
                            QMLHelper.setShort()
                        }
                        freezeMce.freeze()
                    }
                }
            }

            Separator {
                width: parent.width
                title: "Items"
            }

            LabeledCheck {
                text: "Profile controls"
                width: parent.width
                checked: showProfileControls
                onCheckedChanged: QMLHelper.gconfSet("/apps/power-menu-qml/showProfileControls", checked)
            }

            LabeledCheck {
                text: "Switch off"
                width: parent.width
                checked: showPoweroff
                onCheckedChanged: QMLHelper.gconfSet("/apps/power-menu-qml/showPoweroff", checked)
            }

            LabeledCheck {
                text: "Reboot"
                width: parent.width
                checked: showReboot
                onCheckedChanged: QMLHelper.gconfSet("/apps/power-menu-qml/showReboot", checked)
            }

            LabeledCheck {
                text: "Restart mthome"
                width: parent.width
                checked: showKillHome
                onCheckedChanged: QMLHelper.gconfSet("/apps/power-menu-qml/showKillHome", checked)
            }

            LabeledCheck {
                text: "Restart sysuid"
                width: parent.width
                checked: showKillSysuid
                onCheckedChanged: QMLHelper.gconfSet("/apps/power-menu-qml/showKillSysuid", checked)
            }

            LabeledCheck {
                text: "Screenshot"
                width: parent.width
                checked: showScreenshot
                onCheckedChanged: QMLHelper.gconfSet("/apps/power-menu-qml/showScreenshot", checked)
            }

            Separator {
                width: parent.width
                title: "Delays"
            }

            Label {
                id: dlabel
                text: "Double press"
            }

            TextField {
                id: dDelay
                width: parent.width
                inputMethodHints: Qt.ImhDigitsOnly
                text: doubleDelay
                placeholderText: "Double press delay in ms"
                Keys.onReturnPressed: {
                    platformCloseSoftwareInputPanel()
                    QMLHelper.setDelay("Double", text)
                    QMLHelper.gconfSet("/apps/power-menu-qml/delay_double", text)
                    freezeMce.freeze()
                    dlabel.text = "Double press"
                }
                onTextChanged: {
                    if (activeFocus)
                        dlabel.text = "Double press. <font color=#ff0000>Press return to save changes</font>"
                }
            }

            Label {
                id: mlabel
                text: "Single press"
            }

            TextField {
                id: mDelay
                width: parent.width
                inputMethodHints: Qt.ImhDigitsOnly
                text: mediumDelay
                placeholderText: "Single press delay in ms"
                Keys.onReturnPressed: {
                    platformCloseSoftwareInputPanel()
                    QMLHelper.setDelay("Medium", text)
                    QMLHelper.gconfSet("/apps/power-menu-qml/delay_medium", text)
                    freezeMce.freeze()
                    mlabel.text = "Single press"
                }
                onTextChanged: {
                    if (activeFocus)
                        mlabel.text = "Single press. <font color=#ff0000>Press return to save changes</font>"
                }
            }

            Label {
                id: llabel
                text: "Long press"
            }

            TextField {
                id: lDelay
                width: parent.width
                inputMethodHints: Qt.ImhDigitsOnly
                text: longDelay
                placeholderText: "Long press delay in ms"
                Keys.onReturnPressed: {
                    platformCloseSoftwareInputPanel()
                    QMLHelper.setDelay("Long", text)
                    QMLHelper.gconfSet("/apps/power-menu-qml/delay_long", text)
                    freezeMce.freeze()
                    llabel.text = "Long press"
                }
                onTextChanged: {
                    if (activeFocus)
                        llabel.text = "Long press. <font color=#ff0000>Press return to save changes</font>"
                }
            }

            Separator {
                width: parent.width
                title: "Remove"
            }

            Button {
                width: 300
                anchors.horizontalCenter: parent.horizontalCenter
                text: "Start service"
                onClicked: {
                    QMLHelper.startService()
                    visible = false
                }
                visible: !isRunning
            }

            Button {
                width: 300
                anchors.horizontalCenter: parent.horizontalCenter
                text: "Remove application"
                onClicked: {
                    QMLHelper.remove()
                    page.closePage()
                }
            }
        }
    /*}

    ScrollDecorator {
        flickableItem: flick
    }*/

    Timer {
        id: freezeMce
        running: false
        triggeredOnStart: false
        repeat: false
        interval: 5000
        onTriggered: {
            animTimer.stop()
            tklock_lock.enabled = true
            tklock_unlock.enabled = true
            tklock_both.enabled = true
            legacy.enabled = true
            double_menu.enabled = true
            double_both.enabled = !double_menu.checked
            dDelay.enabled = true
            mDelay.enabled = true
            lDelay.enabled = true
        }
        function freeze() {
            QMLHelper.restartMce()
            tklock_lock.enabled = false
            tklock_unlock.enabled = false
            tklock_both.enabled = false
            legacy.enabled = false
            double_menu.enabled = false
            double_both.enabled = false
            dDelay.enabled = false
            mDelay.enabled = false
            lDelay.enabled = false
            waitBlur.width = root.width
            animTimer.start()
            start()
        }
    }

    Timer {
        id: animTimer
        interval: freezeMce.interval / 100
        triggeredOnStart: false
        running: false
        repeat: true
        onTriggered: {
            waitBlur.width -= root.width / 100
        }
    }

    Rectangle {
        id: waitBlur
        visible: freezeMce.running
        anchors.top: root.top
        anchors.left: root.left
        height: root.height
        width: root.width
        color: "#80000000"

        Rectangle {
            visible: testRow.visible
            anchors.fill: testRow
            color: "#80000000"
            transform: Rotation { origin.x: testRow.width - testRow.height / 2; origin.y: testRow.height / 2; angle: 270}
        }

        Row {
            id: testRow
            anchors.top: parent.top
            anchors.topMargin: -440
            anchors.right: parent.right
            Repeater {
                width: label.width * model
                model: 4
                Label {
                    id: label
                    font.pixelSize: 25
                    color: "white"
                    text: "working... saving settings... applying changes... "
                }
            }
            transform: Rotation { origin.x: testRow.width - testRow.height / 2; origin.y: testRow.height / 2; angle: 270}
        }
    }
}
